package org.jeecg.modules.system.app.controller;

import java.util.Arrays;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.system.query.QueryRuleEnum;
import org.jeecg.common.util.oConvertUtils;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecg.modules.system.app.dto.*;
import org.jeecg.modules.system.app.entity.AppSitePlace;
import org.jeecg.modules.system.app.service.IAppSitePlaceService;
import org.jeecgframework.poi.excel.ExcelImportUtil;
import org.jeecgframework.poi.excel.def.NormalExcelConstants;
import org.jeecgframework.poi.excel.entity.ExportParams;
import org.jeecgframework.poi.excel.entity.ImportParams;
import org.jeecgframework.poi.excel.view.JeecgEntityExcelView;
import org.jeecg.common.system.base.controller.JeecgController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;
import org.springframework.web.servlet.ModelAndView;
import com.alibaba.fastjson.JSON;
import io.swagger.v3.oas.annotations.tags.Tag;
import io.swagger.v3.oas.annotations.Operation;
import org.jeecg.common.aspect.annotation.AutoLog;
import org.apache.shiro.authz.annotation.RequiresPermissions;
 /**
 * @Description: 商户场所表
 * @Author: jeecg-boot
 * @Date:   2025-07-09
 * @Version: V1.0
 */
@Tag(name="商户场所表")
@RestController
@RequestMapping("/app/appSitePlace")
@Slf4j
public class AppSitePlaceController extends JeecgController<AppSitePlace, IAppSitePlaceService> {
	@Autowired
	private IAppSitePlaceService appSitePlaceService;
	
	/**
	 * 分页列表查询
	 *
	 * @param appSitePlace
	 * @return
	 */
	//@AutoLog(value = "商户场所表-分页列表查询")
	@Operation(summary="商户场所学校、体育馆包场-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<AppSitePlaceCuDTO>> queryPageList(AppSitePlacePageDTO appSitePlace) {
		return Result.OK(appSitePlaceService.queryWitchPriceRulesPage(appSitePlace));
	}
	/**
	 * 分页列表查询
	 *
	 * @param appSitePlace
	 * @return
	 */
	//@AutoLog(value = "商户场所表-分页列表查询")
	@Operation(summary="商户场所无固定场-分页列表查询")
	@GetMapping(value = "/queryUnfixedPageList")
	public Result<IPage<AppSitePlaceUnfixedDTO>> queryUnfixedPageList(AppSitePlaceUnfixedPageDTO appSitePlace) {
		return Result.OK(appSitePlaceService.queryUnfixedPage(appSitePlace));
	}
	
	/**
	 *   添加
	 *
	 * @param appSitePlace
	 * @return
	 */
	@AutoLog(value = "商户场所学校、体育馆包场-添加")
	@Operation(summary="商户场所学校、体育馆包场-添加")
//	@RequiresPermissions("org.jeecg.modules.system.app:nm_site_place:add")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody AppSitePlaceDTO appSitePlace) {
		appSitePlaceService.saveWitchPriceRules(appSitePlace);
		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param appSitePlace
	 * @return
	 */
	@AutoLog(value = "商户场所学校、体育馆包场-编辑")
	@Operation(summary="商户场所学校、体育馆包场-编辑")
//	@RequiresPermissions("org.jeecg.modules.system.app:nm_site_place:edit")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody AppSitePlaceDTO appSitePlace) {
		appSitePlaceService.editWitchPriceRules(appSitePlace);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "商户场所学校、体育馆包场-通过id删除")
	@Operation(summary="商户场所学校、体育馆包场-通过id删除")
//	@RequiresPermissions("org.jeecg.modules.system.app:nm_site_place:delete")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		appSitePlaceService.removeById(id);
		return Result.OK("删除成功!");
	}
	
//	/**
//	 *  批量删除
//	 *
//	 * @param ids
//	 * @return
//	 */
//	@AutoLog(value = "商户场所表-批量删除")
//	@Operation(summary="商户场所表-批量删除")
//	@RequiresPermissions("org.jeecg.modules.system.app:nm_site_place:deleteBatch")
//	@DeleteMapping(value = "/deleteBatch")
//	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
//		this.appSitePlaceService.removeByIds(Arrays.asList(ids.split(",")));
//		return Result.OK("批量删除成功!");
//	}
//
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "商户场所表-通过id查询")
	@Operation(summary="商户场所学校、体育馆包场-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<AppSitePlaceDTO> queryById(@RequestParam(name="id",required=true) String id) {
		return Result.OK(appSitePlaceService.queryWitchPriceRulesById( id));
	}

//    /**
//    * 导出excel
//    *
//    * @param request
//    * @param appSitePlace
//    */
//    @RequiresPermissions("org.jeecg.modules.system.app:nm_site_place:exportXls")
//    @RequestMapping(value = "/exportXls")
//    public ModelAndView exportXls(HttpServletRequest request, AppSitePlace appSitePlace) {
//        return super.exportXls(request, appSitePlace, AppSitePlace.class, "商户场所表");
//    }
//
//    /**
//      * 通过excel导入数据
//    *
//    * @param request
//    * @param response
//    * @return
//    */
//    @RequiresPermissions("org.jeecg.modules.system.app:nm_site_place:importExcel")
//    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
//    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
//        return super.importExcel(request, response, AppSitePlace.class);
//    }

}
